<ol id='status-nav' class='breadcrumb'>
  <li><a href='/status'                           ><i class='fa fa-area-chart'          ></i> Status charts</a ></li>
  <li><a href='/status/alerts'                    ><i class='fa fa-exclamation-triangle'></i> Status alerts</a></li>
  <li><a href='/status/failing/'                  ><i class='fa fa-times'               ></i> Status failing</a></li>
  <li><a href='/status/pending'                   ><i class='fa fa-question-circle'     ></i> Pending jobs</a></li>
  <li><a href='/status/blacklist/'                ><i class='fa fa-hand-paper-o'        ></i> Blacklist</a></li>
  <li><a href='/status/platform-specific-issues/' ><i class='fa fa-eye'                 ></i> Platform-specific issues</a></li>
  <li><a href='/status/slow/'                     ><i class='fa fa-clock-o'             ></i> Slow running tests</a></li>
</ol>
