<ol class="breadcrumb">
  <li class="active">Welcome <%= @user.username %>!</a></li>
</ol>
<header class="well">
  <h1>Self Service</h1>
  <p>You can request a test through the debci UI or view your test request history.</p>
</header>
<div class="row">
  <div class="col-xs-12 col-md-6">
    <a class="well self-service-card text-center" href="/user/<%= @user.username %>/test">
      <div class="self-service-card-icon">
        <span class="glyphicon glyphicon-pencil" aria-hidden="true"></span>
      </div>
      <p>Request Test</p>
    </a>
  </div>
  <div class="col-xs-12 col-md-6">
    <a class="well self-service-card text-center" href="/user/<%= @user.username %>/jobs">
      <div class="self-service-card-icon">
        <span class="glyphicon glyphicon-search" aria-hidden="true"></span>
      </div>
      <p>Job History</p>
    </a>
  </div>
</div>
